# slurmrestapi

API to access and control Slurm.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.0.39
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
  For more information, please visit [https://www.schedmd.com/](https://www.schedmd.com/)

## Requirements.

Python &gt;&#x3D;3.7

## Migration from other generators like python and python-legacy

### Changes

1. This generator uses spec case for all (object) property names and parameter names.
   - So if the spec has a property name like camelCase, it will use camelCase rather than camel_case
   - So you will need to update how you input and read properties to use spec case
2. Endpoint parameters are stored in dictionaries to prevent collisions (explanation below)
   - So you will need to update how you pass data in to endpoints
3. Endpoint responses now include the original response, the deserialized response body, and (todo)the deserialized headers
   - So you will need to update your code to use response.body to access deserialized data
4. All validated data is instantiated in an instance that subclasses all validated Schema classes and Decimal/str/list/tuple/frozendict/NoneClass/BoolClass/bytes/io.FileIO
   - This means that you can use isinstance to check if a payload validated against a schema class
   - This means that no data will be of type None/True/False
     - ingested None will subclass NoneClass
     - ingested True will subclass BoolClass
     - ingested False will subclass BoolClass
     - So if you need to check is True/False/None, instead use instance.is_true_oapg()/.is_false_oapg()/.is_none_oapg()
5. All validated class instances are immutable except for ones based on io.File
   - This is because if properties were changed after validation, that validation would no longer apply
   - So no changing values or property values after a class has been instantiated
6. String + Number types with formats
   - String type data is stored as a string and if you need to access types based on its format like date,
     date-time, uuid, number etc then you will need to use accessor functions on the instance
   - type string + format: See .as_date_oapg, .as_datetime_oapg, .as_decimal_oapg, .as_uuid_oapg
   - type number + format: See .as_float_oapg, .as_int_oapg
   - this was done because openapi/json-schema defines constraints. string data may be type string with no format
     keyword in one schema, and include a format constraint in another schema
   - So if you need to access a string format based type, use as_date_oapg/as_datetime_oapg/as_decimal_oapg/as_uuid_oapg
   - So if you need to access a number format based type, use as_int_oapg/as_float_oapg
7. Property access on AnyType(type unset) or object(dict) schemas
   - Only required keys with valid python names are properties like .someProp and have type hints
   - All optional keys may not exist, so properties are not defined for them
   - One can access optional values with dict_instance['optionalProp'] and KeyError will be raised if it does not exist
   - Use get_item_oapg if you need a way to always get a value whether or not the key exists
     - If the key does not exist, schemas.unset is returned from calling dict_instance.get_item_oapg('optionalProp')
     - All required and optional keys have type hints for this method, and @typing.overload is used
     - A type hint is also generated for additionalProperties accessed using this method
   - So you will need to update you code to use some_instance['optionalProp'] to access optional property
     and additionalProperty values
8. The location of the api classes has changed
   - Api classes are located in your_package.apis.tags.some_api
   - This change was made to eliminate redundant code generation
   - Legacy generators generated the same endpoint twice if it had > 1 tag on it
   - This generator defines an endpoint in one class, then inherits that class to generate
     apis by tags and by paths
   - This change reduces code and allows quicker run time if you use the path apis
     - path apis are at your_package.apis.paths.some_path
   - Those apis will only load their needed models, which is less to load than all of the resources needed in a tag api
   - So you will need to update your import paths to the api classes

### Why are Oapg and \_oapg used in class and method names?

Classes can have arbitrarily named properties set on them
Endpoints can have arbitrary operationId method names set
For those reasons, I use the prefix Oapg and \_oapg to greatly reduce the likelihood of collisions
on protected + public classes/methods.
oapg stands for OpenApi Python Generator.

### Object property spec case

This was done because when payloads are ingested, they can be validated against N number of schemas.
If the input signature used a different property name then that has mutated the payload.
So SchemaA and SchemaB must both see the camelCase spec named variable.
Also it is possible to send in two properties, named camelCase and camel_case in the same payload.
That use case should be support so spec case is used.

### Parameter spec case

Parameters can be included in different locations including:

- query
- path
- header
- cookie

Any of those parameters could use the same parameter names, so if every parameter
was included as an endpoint parameter in a function signature, they would collide.
For that reason, each of those inputs have been separated out into separate typed dictionaries:

- query_params
- path_params
- header_params
- cookie_params

So when updating your code, you will need to pass endpoint parameters in using those
dictionaries.

### Endpoint responses

Endpoint responses have been enriched to now include more information.
Any response reom an endpoint will now include the following properties:
response: urllib3.HTTPResponse
body: typing.Union[Unset, Schema]
headers: typing.Union[Unset, TODO]
Note: response header deserialization has not yet been added

## Installation & Usage

### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/heromicro/slurmrestapi.py.git
```

(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/heromicro/slurmrestapi.py.git`)

Then import the package:

```python
import slurmrestapi
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```

(or `sudo python setup.py install` to install the package for all users)

Then import the package:

```python
import slurmrestapi
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import slurmrestapi
from pprint import pprint
from slurmrestapi.apis.tags import openapi_api
# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = slurmrestapi.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: user
configuration.api_key['user'] = 'YOUR_API_KEY'

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['user'] = 'Bearer'

# Configure Bearer authorization (JWT): bearerAuth
configuration = slurmrestapi.Configuration(
    access_token = 'YOUR_BEARER_TOKEN'
)

# Configure API key authorization: token
configuration.api_key['token'] = 'YOUR_API_KEY'

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['token'] = 'Bearer'

# Enter a context with an instance of the API client
with slurmrestapi.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_api.OpenapiApi(api_client)

    try:
        # Retrieve OpenAPI Specification
        api_instance.openapi_get()
    except slurmrestapi.ApiException as e:
        print("Exception when calling OpenapiApi->openapi_get: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to _http://localhost_

| Class        | Method                                                                                                  | HTTP request                                          | Description                        |
| ------------ | ------------------------------------------------------------------------------------------------------- | ----------------------------------------------------- | ---------------------------------- |
| _OpenapiApi_ | [**openapi_get**](docs/apis/tags/OpenapiApi.md#openapi_get)                                             | **get** /openapi                                      | Retrieve OpenAPI Specification     |
| _OpenapiApi_ | [**openapi_json_get**](docs/apis/tags/OpenapiApi.md#openapi_json_get)                                   | **get** /openapi.json                                 | Retrieve OpenAPI Specification     |
| _OpenapiApi_ | [**openapi_v3_get**](docs/apis/tags/OpenapiApi.md#openapi_v3_get)                                       | **get** /openapi/v3                                   | Retrieve OpenAPI Specification     |
| _OpenapiApi_ | [**openapi_yaml_get**](docs/apis/tags/OpenapiApi.md#openapi_yaml_get)                                   | **get** /openapi.yaml                                 | Retrieve OpenAPI Specification     |
| _SlurmApi_   | [**slurm_v0039_cancel_job**](docs/apis/tags/SlurmApi.md#slurm_v0039_cancel_job)                         | **delete** /slurm/v0.0.39/job/{job_id}                | cancel or signal job               |
| _SlurmApi_   | [**slurm_v0039_delete_node**](docs/apis/tags/SlurmApi.md#slurm_v0039_delete_node)                       | **delete** /slurm/v0.0.39/node/{node_name}            | delete node                        |
| _SlurmApi_   | [**slurm_v0039_diag**](docs/apis/tags/SlurmApi.md#slurm_v0039_diag)                                     | **get** /slurm/v0.0.39/diag                           | get diagnostics                    |
| _SlurmApi_   | [**slurm_v0039_get_job**](docs/apis/tags/SlurmApi.md#slurm_v0039_get_job)                               | **get** /slurm/v0.0.39/job/{job_id}                   | get job info                       |
| _SlurmApi_   | [**slurm_v0039_get_jobs**](docs/apis/tags/SlurmApi.md#slurm_v0039_get_jobs)                             | **get** /slurm/v0.0.39/jobs                           | get list of jobs                   |
| _SlurmApi_   | [**slurm_v0039_get_node**](docs/apis/tags/SlurmApi.md#slurm_v0039_get_node)                             | **get** /slurm/v0.0.39/node/{node_name}               | get node info                      |
| _SlurmApi_   | [**slurm_v0039_get_nodes**](docs/apis/tags/SlurmApi.md#slurm_v0039_get_nodes)                           | **get** /slurm/v0.0.39/nodes                          | get all node info                  |
| _SlurmApi_   | [**slurm_v0039_get_partition**](docs/apis/tags/SlurmApi.md#slurm_v0039_get_partition)                   | **get** /slurm/v0.0.39/partition/{partition_name}     | get partition info                 |
| _SlurmApi_   | [**slurm_v0039_get_partitions**](docs/apis/tags/SlurmApi.md#slurm_v0039_get_partitions)                 | **get** /slurm/v0.0.39/partitions                     | get all partition info             |
| _SlurmApi_   | [**slurm_v0039_get_reservation**](docs/apis/tags/SlurmApi.md#slurm_v0039_get_reservation)               | **get** /slurm/v0.0.39/reservation/{reservation_name} | get reservation info               |
| _SlurmApi_   | [**slurm_v0039_get_reservations**](docs/apis/tags/SlurmApi.md#slurm_v0039_get_reservations)             | **get** /slurm/v0.0.39/reservations                   | get all reservation info           |
| _SlurmApi_   | [**slurm_v0039_ping**](docs/apis/tags/SlurmApi.md#slurm_v0039_ping)                                     | **get** /slurm/v0.0.39/ping                           | ping test                          |
| _SlurmApi_   | [**slurm_v0039_slurmctld_get_licenses**](docs/apis/tags/SlurmApi.md#slurm_v0039_slurmctld_get_licenses) | **get** /slurm/v0.0.39/licenses                       | get all Slurm tracked license info |
| _SlurmApi_   | [**slurm_v0039_submit_job**](docs/apis/tags/SlurmApi.md#slurm_v0039_submit_job)                         | **post** /slurm/v0.0.39/job/submit                    | submit new job                     |
| _SlurmApi_   | [**slurm_v0039_update_job**](docs/apis/tags/SlurmApi.md#slurm_v0039_update_job)                         | **post** /slurm/v0.0.39/job/{job_id}                  | update job                         |
| _SlurmApi_   | [**slurm_v0039_update_node**](docs/apis/tags/SlurmApi.md#slurm_v0039_update_node)                       | **post** /slurm/v0.0.39/node/{node_name}              | update node properties             |
| _SlurmApi_   | [**slurmdb_v0039_add_clusters**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_add_clusters)                 | **post** /slurmdb/v0.0.39/clusters                    | Add clusters                       |
| _SlurmApi_   | [**slurmdb_v0039_add_wckeys**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_add_wckeys)                     | **post** /slurmdb/v0.0.39/wckeys                      | Add wckeys                         |
| _SlurmApi_   | [**slurmdb_v0039_delete_account**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_delete_account)             | **delete** /slurmdb/v0.0.39/account/{account_name}    | Delete account                     |
| _SlurmApi_   | [**slurmdb_v0039_delete_association**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_delete_association)     | **delete** /slurmdb/v0.0.39/association               | Delete association                 |
| _SlurmApi_   | [**slurmdb_v0039_delete_associations**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_delete_associations)   | **delete** /slurmdb/v0.0.39/associations              | Delete associations                |
| _SlurmApi_   | [**slurmdb_v0039_delete_cluster**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_delete_cluster)             | **delete** /slurmdb/v0.0.39/cluster/{cluster_name}    | Delete cluster                     |
| _SlurmApi_   | [**slurmdb_v0039_delete_qos**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_delete_qos)                     | **delete** /slurmdb/v0.0.39/qos/{qos_name}            | Delete QOS                         |
| _SlurmApi_   | [**slurmdb_v0039_delete_user**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_delete_user)                   | **delete** /slurmdb/v0.0.39/user/{user_name}          | Delete user                        |
| _SlurmApi_   | [**slurmdb_v0039_delete_wckey**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_delete_wckey)                 | **delete** /slurmdb/v0.0.39/wckey/{wckey}             | Delete wckey                       |
| _SlurmApi_   | [**slurmdb_v0039_diag**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_diag)                                 | **get** /slurmdb/v0.0.39/diag                         | Get slurmdb diagnostics            |
| _SlurmApi_   | [**slurmdb_v0039_get_account**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_get_account)                   | **get** /slurmdb/v0.0.39/account/{account_name}       | Get account info                   |
| _SlurmApi_   | [**slurmdb_v0039_get_accounts**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_get_accounts)                 | **get** /slurmdb/v0.0.39/accounts                     | Get account list                   |
| _SlurmApi_   | [**slurmdb_v0039_get_association**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_get_association)           | **get** /slurmdb/v0.0.39/association                  | Get association info               |
| _SlurmApi_   | [**slurmdb_v0039_get_associations**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_get_associations)         | **get** /slurmdb/v0.0.39/associations                 | Get association list               |
| _SlurmApi_   | [**slurmdb_v0039_get_cluster**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_get_cluster)                   | **get** /slurmdb/v0.0.39/cluster/{cluster_name}       | Get cluster info                   |
| _SlurmApi_   | [**slurmdb_v0039_get_clusters**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_get_clusters)                 | **get** /slurmdb/v0.0.39/clusters                     | Get cluster list                   |
| _SlurmApi_   | [**slurmdb_v0039_get_config**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_get_config)                     | **get** /slurmdb/v0.0.39/config                       | Dump all configuration information |
| _SlurmApi_   | [**slurmdb_v0039_get_job**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_get_job)                           | **get** /slurmdb/v0.0.39/job/{job_id}                 | Get job info                       |
| _SlurmApi_   | [**slurmdb_v0039_get_jobs**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_get_jobs)                         | **get** /slurmdb/v0.0.39/jobs                         | Get job list                       |
| _SlurmApi_   | [**slurmdb_v0039_get_qos**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_get_qos)                           | **get** /slurmdb/v0.0.39/qos                          | Get QOS list                       |
| _SlurmApi_   | [**slurmdb_v0039_get_single_qos**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_get_single_qos)             | **get** /slurmdb/v0.0.39/qos/{qos_name}               | Get QOS info                       |
| _SlurmApi_   | [**slurmdb_v0039_get_tres**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_get_tres)                         | **get** /slurmdb/v0.0.39/tres                         | Get TRES info                      |
| _SlurmApi_   | [**slurmdb_v0039_get_user**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_get_user)                         | **get** /slurmdb/v0.0.39/user/{user_name}             | Get user info                      |
| _SlurmApi_   | [**slurmdb_v0039_get_users**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_get_users)                       | **get** /slurmdb/v0.0.39/users                        | Get user list                      |
| _SlurmApi_   | [**slurmdb_v0039_get_wckey**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_get_wckey)                       | **get** /slurmdb/v0.0.39/wckey/{wckey}                | Get wckey info                     |
| _SlurmApi_   | [**slurmdb_v0039_get_wckeys**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_get_wckeys)                     | **get** /slurmdb/v0.0.39/wckeys                       | Get wckey list                     |
| _SlurmApi_   | [**slurmdb_v0039_set_config**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_set_config)                     | **post** /slurmdb/v0.0.39/config                      | Load all configuration information |
| _SlurmApi_   | [**slurmdb_v0039_update_accounts**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_update_accounts)           | **post** /slurmdb/v0.0.39/accounts                    | Update accounts                    |
| _SlurmApi_   | [**slurmdb_v0039_update_associations**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_update_associations)   | **post** /slurmdb/v0.0.39/associations                | Set associations info              |
| _SlurmApi_   | [**slurmdb_v0039_update_qos**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_update_qos)                     | **post** /slurmdb/v0.0.39/qos                         | Set QOS info                       |
| _SlurmApi_   | [**slurmdb_v0039_update_tres**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_update_tres)                   | **post** /slurmdb/v0.0.39/tres                        | Set TRES info                      |
| _SlurmApi_   | [**slurmdb_v0039_update_users**](docs/apis/tags/SlurmApi.md#slurmdb_v0039_update_users)                 | **post** /slurmdb/v0.0.39/users                       | Update user                        |

## Documentation For Models

- [Dbv0039AccountInfo](docs/models/Dbv0039AccountInfo.md)
- [Dbv0039AssociationsInfo](docs/models/Dbv0039AssociationsInfo.md)
- [Dbv0039ClustersInfo](docs/models/Dbv0039ClustersInfo.md)
- [Dbv0039ConfigInfo](docs/models/Dbv0039ConfigInfo.md)
- [Dbv0039Diag](docs/models/Dbv0039Diag.md)
- [Dbv0039Error](docs/models/Dbv0039Error.md)
- [Dbv0039Errors](docs/models/Dbv0039Errors.md)
- [Dbv0039JobInfo](docs/models/Dbv0039JobInfo.md)
- [Dbv0039Meta](docs/models/Dbv0039Meta.md)
- [Dbv0039QosInfo](docs/models/Dbv0039QosInfo.md)
- [Dbv0039ResponseAssociationsDelete](docs/models/Dbv0039ResponseAssociationsDelete.md)
- [Dbv0039SetConfig](docs/models/Dbv0039SetConfig.md)
- [Dbv0039TresInfo](docs/models/Dbv0039TresInfo.md)
- [Dbv0039TresUpdate](docs/models/Dbv0039TresUpdate.md)
- [Dbv0039UpdateQos](docs/models/Dbv0039UpdateQos.md)
- [Dbv0039UpdateUsers](docs/models/Dbv0039UpdateUsers.md)
- [Dbv0039UserInfo](docs/models/Dbv0039UserInfo.md)
- [Dbv0039Warning](docs/models/Dbv0039Warning.md)
- [Dbv0039Warnings](docs/models/Dbv0039Warnings.md)
- [Dbv0039WckeyInfo](docs/models/Dbv0039WckeyInfo.md)
- [Status](docs/models/Status.md)
- [V0039Account](docs/models/V0039Account.md)
- [V0039AccountList](docs/models/V0039AccountList.md)
- [V0039Accounting](docs/models/V0039Accounting.md)
- [V0039AccountingList](docs/models/V0039AccountingList.md)
- [V0039AcctGatherEnergy](docs/models/V0039AcctGatherEnergy.md)
- [V0039AcctGatherEnergyPtr](docs/models/V0039AcctGatherEnergyPtr.md)
- [V0039Assoc](docs/models/V0039Assoc.md)
- [V0039AssocId](docs/models/V0039AssocId.md)
- [V0039AssocList](docs/models/V0039AssocList.md)
- [V0039AssocShort](docs/models/V0039AssocShort.md)
- [V0039AssocShortList](docs/models/V0039AssocShortList.md)
- [V0039AssocShortPtr](docs/models/V0039AssocShortPtr.md)
- [V0039AssocUsage](docs/models/V0039AssocUsage.md)
- [V0039AssocUsagePtr](docs/models/V0039AssocUsagePtr.md)
- [V0039ClusterRec](docs/models/V0039ClusterRec.md)
- [V0039ClusterRecList](docs/models/V0039ClusterRecList.md)
- [V0039ControllerPing](docs/models/V0039ControllerPing.md)
- [V0039ControllerPingArray](docs/models/V0039ControllerPingArray.md)
- [V0039Coord](docs/models/V0039Coord.md)
- [V0039CoordList](docs/models/V0039CoordList.md)
- [V0039CronEntry](docs/models/V0039CronEntry.md)
- [V0039CronEntryPtr](docs/models/V0039CronEntryPtr.md)
- [V0039CsvList](docs/models/V0039CsvList.md)
- [V0039Diag](docs/models/V0039Diag.md)
- [V0039Error](docs/models/V0039Error.md)
- [V0039Errors](docs/models/V0039Errors.md)
- [V0039ExtSensorsData](docs/models/V0039ExtSensorsData.md)
- [V0039ExtSensorsDataPtr](docs/models/V0039ExtSensorsDataPtr.md)
- [V0039Float64NoVal](docs/models/V0039Float64NoVal.md)
- [V0039Hostlist](docs/models/V0039Hostlist.md)
- [V0039HostlistString](docs/models/V0039HostlistString.md)
- [V0039Job](docs/models/V0039Job.md)
- [V0039JobArrayResponseMsg](docs/models/V0039JobArrayResponseMsg.md)
- [V0039JobArrayResponseMsgPtr](docs/models/V0039JobArrayResponseMsgPtr.md)
- [V0039JobDescMsg](docs/models/V0039JobDescMsg.md)
- [V0039JobDescMsgArgv](docs/models/V0039JobDescMsgArgv.md)
- [V0039JobDescMsgEnv](docs/models/V0039JobDescMsgEnv.md)
- [V0039JobDescMsgList](docs/models/V0039JobDescMsgList.md)
- [V0039JobDescMsgSpankEnv](docs/models/V0039JobDescMsgSpankEnv.md)
- [V0039JobExclusive](docs/models/V0039JobExclusive.md)
- [V0039JobExitCode](docs/models/V0039JobExitCode.md)
- [V0039JobInfo](docs/models/V0039JobInfo.md)
- [V0039JobInfoGresDetail](docs/models/V0039JobInfoGresDetail.md)
- [V0039JobInfoMsg](docs/models/V0039JobInfoMsg.md)
- [V0039JobList](docs/models/V0039JobList.md)
- [V0039JobMemPerCpu](docs/models/V0039JobMemPerCpu.md)
- [V0039JobMemPerNode](docs/models/V0039JobMemPerNode.md)
- [V0039JobRes](docs/models/V0039JobRes.md)
- [V0039JobResNodes](docs/models/V0039JobResNodes.md)
- [V0039JobResPtr](docs/models/V0039JobResPtr.md)
- [V0039JobSubmission](docs/models/V0039JobSubmission.md)
- [V0039JobSubmissionResponse](docs/models/V0039JobSubmissionResponse.md)
- [V0039JobUpdateResponse](docs/models/V0039JobUpdateResponse.md)
- [V0039JobsResponse](docs/models/V0039JobsResponse.md)
- [V0039License](docs/models/V0039License.md)
- [V0039Licenses](docs/models/V0039Licenses.md)
- [V0039LicensesInfo](docs/models/V0039LicensesInfo.md)
- [V0039Meta](docs/models/V0039Meta.md)
- [V0039Node](docs/models/V0039Node.md)
- [V0039Nodes](docs/models/V0039Nodes.md)
- [V0039NodesResponse](docs/models/V0039NodesResponse.md)
- [V0039PartitionInfo](docs/models/V0039PartitionInfo.md)
- [V0039PartitionInfoArray](docs/models/V0039PartitionInfoArray.md)
- [V0039PartitionsResponse](docs/models/V0039PartitionsResponse.md)
- [V0039Pings](docs/models/V0039Pings.md)
- [V0039PowerMgmtData](docs/models/V0039PowerMgmtData.md)
- [V0039PowerMgmtDataPtr](docs/models/V0039PowerMgmtDataPtr.md)
- [V0039Qos](docs/models/V0039Qos.md)
- [V0039QosList](docs/models/V0039QosList.md)
- [V0039QosPreemptList](docs/models/V0039QosPreemptList.md)
- [V0039QosStringIdList](docs/models/V0039QosStringIdList.md)
- [V0039ReservationCoreSpec](docs/models/V0039ReservationCoreSpec.md)
- [V0039ReservationInfo](docs/models/V0039ReservationInfo.md)
- [V0039ReservationInfoArray](docs/models/V0039ReservationInfoArray.md)
- [V0039ReservationInfoCoreSpec](docs/models/V0039ReservationInfoCoreSpec.md)
- [V0039ReservationsResponse](docs/models/V0039ReservationsResponse.md)
- [V0039RollupStats](docs/models/V0039RollupStats.md)
- [V0039RollupStatsPtr](docs/models/V0039RollupStatsPtr.md)
- [V0039SlurmStepId](docs/models/V0039SlurmStepId.md)
- [V0039StatsMsg](docs/models/V0039StatsMsg.md)
- [V0039StatsMsgRpcsByType](docs/models/V0039StatsMsgRpcsByType.md)
- [V0039StatsMsgRpcsByUser](docs/models/V0039StatsMsgRpcsByUser.md)
- [V0039StatsRec](docs/models/V0039StatsRec.md)
- [V0039StatsRecPtr](docs/models/V0039StatsRecPtr.md)
- [V0039StatsRpc](docs/models/V0039StatsRpc.md)
- [V0039StatsRpcList](docs/models/V0039StatsRpcList.md)
- [V0039StatsUser](docs/models/V0039StatsUser.md)
- [V0039StatsUserList](docs/models/V0039StatsUserList.md)
- [V0039Step](docs/models/V0039Step.md)
- [V0039StepList](docs/models/V0039StepList.md)
- [V0039StepNodes](docs/models/V0039StepNodes.md)
- [V0039StepTresReqMax](docs/models/V0039StepTresReqMax.md)
- [V0039StepTresReqMin](docs/models/V0039StepTresReqMin.md)
- [V0039StepTresUsageMax](docs/models/V0039StepTresUsageMax.md)
- [V0039StepTresUsageMin](docs/models/V0039StepTresUsageMin.md)
- [V0039StringArray](docs/models/V0039StringArray.md)
- [V0039Tres](docs/models/V0039Tres.md)
- [V0039TresList](docs/models/V0039TresList.md)
- [V0039TresStr](docs/models/V0039TresStr.md)
- [V0039Uint16NoVal](docs/models/V0039Uint16NoVal.md)
- [V0039Uint32NoVal](docs/models/V0039Uint32NoVal.md)
- [V0039Uint64NoVal](docs/models/V0039Uint64NoVal.md)
- [V0039UpdateNodeMsg](docs/models/V0039UpdateNodeMsg.md)
- [V0039User](docs/models/V0039User.md)
- [V0039UserList](docs/models/V0039UserList.md)
- [V0039Warning](docs/models/V0039Warning.md)
- [V0039Warnings](docs/models/V0039Warnings.md)
- [V0039Wckey](docs/models/V0039Wckey.md)
- [V0039WckeyList](docs/models/V0039WckeyList.md)
- [V0039WckeyTag](docs/models/V0039WckeyTag.md)

## Documentation For Authorization

Authentication schemes defined for the API:
<a id="user"></a>

### user

- **Type**: API key
- **API key parameter name**: X-SLURM-USER-NAME
- **Location**: HTTP header

<a id="token"></a>

### token

- **Type**: API key
- **API key parameter name**: X-SLURM-USER-TOKEN
- **Location**: HTTP header

<a id="bearerAuth"></a>

### bearerAuth

- **Type**: Bearer authentication (JWT)

## Author

sales@schedmd.com
sales@schedmd.com

## Notes for Large OpenAPI documents

If the OpenAPI document is large, imports in slurmrestapi.apis and slurmrestapi.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:

- `from slurmrestapi.apis.default_api import DefaultApi`
- `from slurmrestapi.model.pet import Pet`

Solution 1:
Before importing the package, adjust the maximum recursion limit as shown below:

```
import sys
sys.setrecursionlimit(1500)
import slurmrestapi
from slurmrestapi.apis import *
from slurmrestapi.models import *
```
